bbprep.generators.ETKDG
=======================

.. currentmodule:: bbprep.generators

.. autoclass:: ETKDG
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ETKDG.generate_conformers
   
   

   
   
   